'use strict';

var _fs = require('fs');

var fs = _interopRequireWildcard(_fs);

var _tap = require('tap');

var tap = _interopRequireWildcard(_tap);

var _remark = require('remark');

var _remark2 = _interopRequireDefault(_remark);

var _index = require('../lib/index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var MAXWEIGHT = '#';
var MINWEIGHT = '######';

tap.test('Add heading weight', function (assert) {
  var expected = '# Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1 }).process('## Heading');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove heading weight', function (assert) {
  var expected = '## Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1 }).process('# Heading');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Add max heading weight', function (assert) {
  var expected = MAXWEIGHT + ' Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10 }).process('## Heading');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading weight', function (assert) {
  var expected = MINWEIGHT + ' Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10 }).process('## Heading');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading w/o preserve', function (assert) {
  var expected = ' Heading\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, preserve: false }).process('## Heading');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Add heading weight after', function (assert) {
  var expected = '## Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1, after: '## Heading 1' }).process('## Heading 1\n# Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove heading weight after', function (assert) {
  var expected = '## Heading 1\n\n# Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1, after: '## Heading 1' }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Add max heading weight after', function (assert) {
  var expected = '## Heading 1\n\n' + MAXWEIGHT + ' Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10, after: '## Heading 1' }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading weight after', function (assert) {
  var expected = '## Heading 1\n\n' + MINWEIGHT + ' Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, after: '## Heading 1' }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading weight w/o preserve after', function (assert) {
  var expected = '## Heading 1\n\n Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, after: '## Heading 1', preserve: false }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Add heading weight before', function (assert) {
  var expected = '### Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove heading weight before', function (assert) {
  var expected = '# Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Add max heading weight before', function (assert) {
  var expected = MAXWEIGHT + ' Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading weight before', function (assert) {
  var expected = MINWEIGHT + ' Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, before: '## Heading 2' }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading weight w/o preserve before', function (assert) {
  var expected = ' Heading 1\n\n## Heading 2\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, before: '## Heading 2', preserve: false }).process('## Heading 1\n## Heading 2');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Add heading weight between', function (assert) {
  var expected = '## Heading 1\n\n### Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: -1, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove heading weight between', function (assert) {
  var expected = '## Heading 1\n\n# Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: 1, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Add max heading weight between', function (assert) {
  var expected = '## Heading 1\n\n' + MAXWEIGHT + ' Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: 10, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading weight between', function (assert) {
  var expected = '## Heading 1\n\n' + MINWEIGHT + ' Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, between: ['## Heading 1', '## Heading 3'] }).process('## Heading 1\n## Heading 2\n## Heading 3');

  assert.equal(actual, expected);
  assert.end();
});

tap.test('Remove max heading weight w/o preserve between', function (assert) {
  var expected = '## Heading 1\n\n Heading 2\n\n## Heading 3\n';
  var actual = _remark2.default.use(_index2.default, { weight: -10, between: ['## Heading 1', '## Heading 3'], preserve: false }).process('## Heading 1\n## Heading 2\n## Heading 3');

  assert.equal(actual, expected);
  assert.end();
});